Exception: WebPipe::Plug::InvalidPlugError Private

Inherits:
ArgumentError
  • Object
show all
Defined in:
lib/web_pipe/plug.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Error raised when no operation can be resolved from a Spec.

Instance Method Summary collapse

Constructor Details

#initialize(name) ⇒ InvalidPlugError

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of InvalidPlugError.

Parameters:

  • name (Any)

    Name for the plug that can't be resolved



26
27
28
29
30
31
32
33
34
# File 'lib/web_pipe/plug.rb', line 26

def initialize(name)
  super(
    "      Plug with name +\#{name}+ is invalid. It must be something\n      callable, an instance method when no operation is given,\n      or something callable registered in the container.\"\n    MSG\n  )\nend\n"